@@ -18,7 +18,7 @@ use crate::{
     metrics::{vmaf::validate_libvmaf, xpsnr::validate_libxpsnr},
     parse::valid_params,
     target_quality::TargetQuality,
-    vapoursynth::{VSZipVersion, VapoursynthPlugins},
+    vapoursynth::{CacheSource, VSZipVersion, VapoursynthPlugins},
     ChunkMethod,
     ChunkOrdering,
     Input,
@@ -101,6 +101,7 @@ pub struct EncodeArgs {
     pub photon_noise_size:   (Option<u32>, Option<u32>), // Width and Height
     pub chroma_noise:        bool,
     pub zones:               Option<PathBuf>,
+    pub cache_mode:          CacheSource,
 
     // FFmpeg params
     pub ffmpeg_filter_args: Vec<String>,
