@@ -1,5 +1,5 @@
 use std::{
-    collections::HashSet,
+    fmt::Display,
     fs::{create_dir_all, File},
     io::Write,
     path::{absolute, Path, PathBuf},
@@ -9,6 +9,8 @@ use std::{
 use anyhow::{anyhow, bail, Context};
 use av_format::rational::Rational64;
 use path_abs::{PathAbs, PathInfo};
+use serde::{Deserialize, Serialize};
+use strum::{EnumString, IntoStaticStr};
 use tracing::info;
 use vapoursynth::{
     core::CoreRef,
@@ -28,6 +30,23 @@ use crate::{
     InputPixelFormat,
 };
 
+#[derive(
+    Serialize, PartialEq, Debug, Clone, Copy, EnumString, IntoStaticStr, Hash, Eq, Deserialize,
+)]
+pub enum CacheSource {
+    #[strum(serialize = "source")]
+    SOURCE,
+    #[strum(serialize = "temp")]
+    TEMP,
+}
+
+impl Display for CacheSource {
+    #[inline]
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.write_str(<&'static str>::from(self))
+    }
+}
+
 /// Contains a list of installed Vapoursynth plugins which may be used by av1an
 #[derive(Debug, Clone, Copy)]
 pub struct VapoursynthPlugins {
@@ -72,27 +91,14 @@ pub fn get_vapoursynth_plugins() -> anyhow::Result<VapoursynthPlugins> {
     let env = Environment::new().expect("Failed to initialize VapourSynth environment");
     let core = env.get_core().expect("Failed to get VapourSynth core");
 
-    let plugins = core.plugins();
-    let plugins = plugins
-        .keys()
-        .filter_map(|plugin| {
-            plugins
-                .get::<&[u8]>(plugin)
-                .ok()
-                .and_then(|slice| simdutf8::basic::from_utf8(slice).ok())
-                .and_then(|s| s.split(';').nth(1))
-                .map(ToOwned::to_owned)
-        })
-        .collect::<HashSet<_>>();
-
     Ok(VapoursynthPlugins {
-        lsmash:     plugins.contains(PluginId::Lsmash.as_str()),
-        ffms2:      plugins.contains(PluginId::Ffms2.as_str()),
-        dgdecnv:    plugins.contains(PluginId::DGDecNV.as_str()),
-        bestsource: plugins.contains(PluginId::BestSource.as_str()),
-        julek:      plugins.contains(PluginId::Julek.as_str()),
-        vszip:      if plugins.contains(PluginId::Vszip.as_str()) {
-            if is_vszip_r7_or_newer(&env) {
+        lsmash:     core.get_plugin_by_id(PluginId::Lsmash.as_str())?.is_some(),
+        ffms2:      core.get_plugin_by_id(PluginId::Ffms2.as_str())?.is_some(),
+        dgdecnv:    core.get_plugin_by_id(PluginId::DGDecNV.as_str())?.is_some(),
+        bestsource: core.get_plugin_by_id(PluginId::BestSource.as_str())?.is_some(),
+        julek:      core.get_plugin_by_id(PluginId::Julek.as_str())?.is_some(),
+        vszip:      if let Some(plugin) = core.get_plugin_by_id(PluginId::Vszip.as_str())? {
+            if is_vszip_r7_or_newer(plugin)? {
                 VSZipVersion::New
             } else {
                 VSZipVersion::Legacy
@@ -100,39 +106,15 @@ pub fn get_vapoursynth_plugins() -> anyhow::Result<VapoursynthPlugins> {
         } else {
             VSZipVersion::None
         },
-        vship:      plugins.contains(PluginId::Vship.as_str()),
+        vship:      core.get_plugin_by_id(PluginId::Vship.as_str())?.is_some(),
     })
 }
 
 // There is no way to get the version of a plugin
 // so check for a function signature instead
-fn is_vszip_r7_or_newer(env: &Environment) -> bool {
-    let core = env.get_core().expect("Failed to get VapourSynth core");
-
-    let vszip = get_plugin(core, PluginId::Vszip).expect("Failed to get vszip plugin");
-    let functions_map = vszip.functions();
-    let functions: Vec<(String, Vec<String>)> = functions_map
-        .keys()
-        .filter_map(|name| {
-            functions_map
-                .get::<&[u8]>(name)
-                .ok()
-                .and_then(|slice| simdutf8::basic::from_utf8(slice).ok())
-                .map(|f| {
-                    let mut split = f.split(';');
-                    (
-                        split.next().expect("Function name is missing").to_string(),
-                        split
-                            .filter(|s| !s.is_empty())
-                            .map(ToOwned::to_owned)
-                            .collect::<Vec<String>>(),
-                    )
-                })
-        })
-        .collect();
-
+fn is_vszip_r7_or_newer(plugin: Plugin) -> anyhow::Result<bool> {
     // R7 adds XPSNR and also introduces breaking changes the API
-    functions.iter().any(|(name, _)| name == "XPSNR")
+    Ok(plugin.get_plugin_function_by_name("XPSNR")?.is_some())
 }
 
 #[inline]
@@ -154,11 +136,7 @@ pub fn get_clip_info(source: &Input, vspipe_args_map: &OwnedMap) -> anyhow::Resu
             .context(CONTEXT_MSG)?;
     }
 
-    #[cfg(feature = "vapoursynth_new_api")]
     let (node, _) = environment.get_output(OUTPUT_INDEX)?;
-    #[cfg(not(feature = "vapoursynth_new_api"))]
-    let node = environment.get_output(OUTPUT_INDEX).unwrap();
-
     let info = node.info();
 
     Ok(ClipInfo {
@@ -179,9 +157,6 @@ pub fn get_clip_info(source: &Input, vspipe_args_map: &OwnedMap) -> anyhow::Resu
 /// evaluated on a script.
 fn get_num_frames(info: &VideoInfo) -> anyhow::Result<usize> {
     let num_frames = {
-        if Property::Variable == info.format {
-            bail!("Cannot output clips with varying format");
-        }
         if Property::Variable == info.resolution {
             bail!("Cannot output clips with varying dimensions");
         }
@@ -189,20 +164,7 @@ fn get_num_frames(info: &VideoInfo) -> anyhow::Result<usize> {
             bail!("Cannot output clips with varying framerate");
         }
 
-        #[cfg(feature = "vapoursynth_new_api")]
-        let num_frames = info.num_frames;
-
-        #[cfg(not(feature = "vapoursynth_new_api"))]
-        let num_frames = {
-            match info.num_frames {
-                Property::Variable => {
-                    bail!("Cannot output clips with unknown length");
-                },
-                Property::Constant(x) => x,
-            }
-        };
-
-        num_frames
+        info.num_frames
     };
 
     assert!(num_frames != 0, "vapoursynth reported 0 frames");
@@ -223,14 +185,7 @@ fn get_frame_rate(info: &VideoInfo) -> anyhow::Result<Rational64> {
 /// Get the bit depth from an environment that has already been
 /// evaluated on a script.
 fn get_bit_depth(info: &VideoInfo) -> anyhow::Result<usize> {
-    let bits_per_sample = {
-        match info.format {
-            Property::Variable => {
-                bail!("Cannot output clips with variable format");
-            },
-            Property::Constant(x) => x.bits_per_sample(),
-        }
-    };
+    let bits_per_sample = info.format.bits_per_sample();
 
     Ok(bits_per_sample as usize)
 }
@@ -256,11 +211,7 @@ fn get_transfer(env: &Environment) -> anyhow::Result<u8> {
     // Get the output node.
     const OUTPUT_INDEX: i32 = 0;
 
-    #[cfg(feature = "vapoursynth_new_api")]
     let (node, _) = env.get_output(OUTPUT_INDEX)?;
-    #[cfg(not(feature = "vapoursynth_new_api"))]
-    let node = env.get_output(OUTPUT_INDEX).unwrap();
-
     let frame = node.get_frame(0).context("get_transfer")?;
     let transfer = frame.props().get::<i64>("_Transfer").map(|val| val as u8).unwrap_or(2);
 
@@ -336,7 +287,7 @@ fn import_lsmash<'core>(
     lsmash
         .invoke("LWLibavSource", &arguments)
         .map_err(|_| anyhow::anyhow!(error_message.clone()))?
-        .get_node("clip")
+        .get_video_node("clip")
         .map_err(|_| anyhow::anyhow!(error_message.clone()))
 }
 
@@ -368,7 +319,7 @@ fn import_ffms2<'core>(
     ffms2
         .invoke("Source", &arguments)
         .map_err(|_| anyhow::anyhow!(error_message.clone()))?
-        .get_node("clip")
+        .get_video_node("clip")
         .map_err(|_| anyhow::anyhow!(error_message.clone()))
 }
 
@@ -404,7 +355,7 @@ fn import_bestsource<'core>(
     bestsource
         .invoke("VideoSource", &arguments)
         .map_err(|_| anyhow::anyhow!(error_message.clone()))?
-        .get_node("clip")
+        .get_video_node("clip")
         .map_err(|_| anyhow::anyhow!(error_message.clone()))
 }
 
@@ -444,7 +395,7 @@ fn trim_node<'core>(
 
     std.invoke("Trim", &arguments)
         .map_err(|_| anyhow::anyhow!(error_message.clone()))?
-        .get_node("clip")
+        .get_video_node("clip")
         .map_err(|_| anyhow::anyhow!(error_message.clone()))
 }
 
@@ -483,7 +434,7 @@ pub fn resize_node<'core>(
 
     std.invoke("Bicubic", &arguments)
         .map_err(|_| anyhow::anyhow!(error_message.clone()))?
-        .get_node("clip")
+        .get_video_node("clip")
         .map_err(|_| anyhow::anyhow!(error_message.clone()))
 }
 
@@ -504,7 +455,7 @@ fn select_every<'core>(
 
     std.invoke("SelectEvery", &arguments)
         .map_err(|_| anyhow::anyhow!(error_message.clone()))?
-        .get_node("clip")
+        .get_video_node("clip")
         .map_err(|_| anyhow::anyhow!(error_message.clone()))
 }
 
@@ -559,7 +510,7 @@ fn compare_ssimulacra2<'core>(
             &arguments,
         )
         .map_err(|_| anyhow::anyhow!(error_message.clone()))?
-        .get_node("clip")
+        .get_video_node("clip")
         .map_err(|_| anyhow::anyhow!(error_message.clone()))?;
 
     Ok((
@@ -646,7 +597,7 @@ fn compare_butteraugli<'core>(
             &arguments,
         )
         .map_err(|_| anyhow::anyhow!(error_message.clone()))?
-        .get_node("clip")
+        .get_video_node("clip")
         .map_err(|_| anyhow::anyhow!(error_message.clone()))?;
 
     Ok((
@@ -707,37 +658,31 @@ fn compare_xpsnr<'core>(
     plugin
         .invoke("XPSNR", &arguments)
         .map_err(|_| anyhow::anyhow!(error_message.clone()))?
-        .get_node("clip")
+        .get_video_node("clip")
         .map_err(|_| anyhow::anyhow!(error_message.clone()))
 }
 
 #[inline]
-pub fn create_vs_file(
-    temp: &str,
-    source: &Path,
-    chunk_method: ChunkMethod,
-    scene_detection_downscale_height: Option<usize>,
-    scene_detection_pixel_format: Option<FFPixelFormat>,
-    scene_detection_scaler: &str,
-    is_proxy: bool,
-) -> anyhow::Result<(PathBuf, bool)> {
-    let (load_script_text, cache_file_already_exists) = generate_loadscript_text(
-        temp,
-        source,
-        chunk_method,
-        scene_detection_downscale_height,
-        scene_detection_pixel_format,
-        scene_detection_scaler,
-        is_proxy,
-    )?;
+pub fn create_vs_file(loadscript_args: &LoadscriptArgs) -> anyhow::Result<(PathBuf, bool)> {
+    let (load_script_text, cache_file_already_exists) =
+        generate_loadscript_text(&LoadscriptArgs {
+            temp:                             loadscript_args.temp,
+            source:                           loadscript_args.source,
+            chunk_method:                     loadscript_args.chunk_method,
+            scene_detection_downscale_height: loadscript_args.scene_detection_downscale_height,
+            scene_detection_pixel_format:     loadscript_args.scene_detection_pixel_format,
+            scene_detection_scaler:           loadscript_args.scene_detection_scaler,
+            is_proxy:                         loadscript_args.is_proxy,
+            cache_mode:                       loadscript_args.cache_mode,
+        })?;
     // Ensure the temp folder exists
-    let temp: &Path = temp.as_ref();
+    let temp: &Path = loadscript_args.temp.as_ref();
     let split_folder = temp.join("split");
     create_dir_all(&split_folder)?;
 
-    if chunk_method == ChunkMethod::DGDECNV {
-        let absolute_source = absolute(source)?;
-        let dgindexnv_output = split_folder.join(if is_proxy {
+    if loadscript_args.chunk_method == ChunkMethod::DGDECNV {
+        let absolute_source = absolute(loadscript_args.source)?;
+        let dgindexnv_output = split_folder.join(if loadscript_args.is_proxy {
             "index_proxy.dgi"
         } else {
             "index.dgi"
@@ -757,7 +702,7 @@ pub fn create_vs_file(
         }
     }
 
-    let load_script_path = split_folder.join(if is_proxy {
+    let load_script_path = split_folder.join(if loadscript_args.is_proxy {
         "loadscript_proxy.vpy"
     } else {
         "loadscript.vpy"
@@ -769,23 +714,32 @@ pub fn create_vs_file(
     Ok((load_script_path, cache_file_already_exists))
 }
 
+pub struct LoadscriptArgs<'a> {
+    pub temp:                             &'a str,
+    pub source:                           &'a Path,
+    pub chunk_method:                     ChunkMethod,
+    pub scene_detection_downscale_height: Option<usize>,
+    pub scene_detection_pixel_format:     Option<FFPixelFormat>,
+    pub scene_detection_scaler:           &'a str,
+    pub is_proxy:                         bool,
+    pub cache_mode:                       CacheSource,
+}
+
 #[inline]
 pub fn generate_loadscript_text(
-    temp: &str,
-    source: &Path,
-    chunk_method: ChunkMethod,
-    scene_detection_downscale_height: Option<usize>,
-    scene_detection_pixel_format: Option<FFPixelFormat>,
-    scene_detection_scaler: &str,
-    is_proxy: bool,
+    loadscript_args: &LoadscriptArgs,
 ) -> anyhow::Result<(String, bool)> {
-    let temp: &Path = temp.as_ref();
-    let source = absolute(source)?;
+    let temp: &Path = loadscript_args.temp.as_ref();
+    let source = absolute(loadscript_args.source)?;
 
     let cache_file = PathAbs::new(temp.join("split").join(format!(
         "{}cache.{}",
-        if is_proxy { "proxy_" } else { "" },
-        match chunk_method {
+        if loadscript_args.is_proxy {
+            "proxy_"
+        } else {
+            ""
+        },
+        match loadscript_args.chunk_method {
             ChunkMethod::FFMS2 => "ffindex",
             ChunkMethod::LSMASH => "lwi",
             ChunkMethod::DGDECNV => "dgi",
@@ -793,7 +747,7 @@ pub fn generate_loadscript_text(
             _ => return Err(anyhow!("invalid chunk method")),
         }
     )))?;
-    let chunk_method_lower = match chunk_method {
+    let chunk_method_lower = match loadscript_args.chunk_method {
         ChunkMethod::FFMS2 => "ffms2",
         ChunkMethod::LSMASH => "lsmash",
         ChunkMethod::DGDECNV => "dgdecnv",
@@ -802,9 +756,9 @@ pub fn generate_loadscript_text(
     };
 
     // Only used for DGDECNV
-    let dgindex_path = match chunk_method {
+    let dgindex_path = match loadscript_args.chunk_method {
         ChunkMethod::DGDECNV => {
-            let dgindexnv_output = temp.join("split").join(if is_proxy {
+            let dgindexnv_output = temp.join("split").join(if loadscript_args.is_proxy {
                 "index_proxy.dgi"
             } else {
                 "index.dgi"
@@ -821,7 +775,7 @@ pub fn generate_loadscript_text(
     let mut load_script_text = include_str!("loadscript.vpy")
         .replace(
             "source = os.environ.get(\"AV1AN_SOURCE\", None)",
-            &format!("source = r\"{}\"", match chunk_method {
+            &format!("source = r\"{}\"", match loadscript_args.chunk_method {
                 ChunkMethod::DGDECNV => dgindex_path.display(),
                 _ => source.display(),
             }),
@@ -831,7 +785,8 @@ pub fn generate_loadscript_text(
             &format!("chunk_method = {chunk_method_lower:?}"),
         );
 
-    if let Some(scene_detection_downscale_height) = scene_detection_downscale_height {
+    if let Some(scene_detection_downscale_height) = loadscript_args.scene_detection_downscale_height
+    {
         load_script_text = load_script_text.replace(
             "downscale_height = os.environ.get(\"AV1AN_DOWNSCALE_HEIGHT\", None)",
             &format!(
@@ -840,7 +795,7 @@ pub fn generate_loadscript_text(
             ),
         );
     }
-    if let Some(scene_detection_pixel_format) = scene_detection_pixel_format {
+    if let Some(scene_detection_pixel_format) = loadscript_args.scene_detection_pixel_format {
         load_script_text = load_script_text.replace(
             "sc_pix_format = os.environ.get(\"AV1AN_PIXEL_FORMAT\", None)",
             &format!(
@@ -849,12 +804,28 @@ pub fn generate_loadscript_text(
             ),
         );
     }
+    if loadscript_args.cache_mode == CacheSource::TEMP {
+        load_script_text = load_script_text.replace(
+            "cache_file = os.environ.get(\"AV1AN_CACHE_FILE\", None)",
+            &format!(
+                "cache_file = r\"{}\"",
+                dunce::simplified(cache_file.as_path()).display(),
+            ),
+        );
+    }
+
+    load_script_text = load_script_text.replace(
+        "cache_mode = os.environ.get(\"AV1AN_CACHE_MODE\", None)",
+        &format!("cache_mode = \"{}\"", loadscript_args.cache_mode),
+    );
+
+    let scene_detection_scaler = loadscript_args.scene_detection_scaler;
     load_script_text = load_script_text.replace(
         "scaler = os.environ.get(\"AV1AN_SCALER\", None)",
         &format!("scaler = os.environ.get(\"AV1AN_SCALER\", {scene_detection_scaler:?})"),
     );
 
-    let cache_file_already_exists = match chunk_method {
+    let cache_file_already_exists = match loadscript_args.chunk_method {
         ChunkMethod::DGDECNV => dgindex_path.exists(),
         _ => cache_file.exists(),
     };
